@@ -17,7 +17,7 @@ class Artwork with Showable, Collectionable  {
 
 =head1 NAME
 
-Art::Artwork - The base thing producted by artists
+Art::Artwork -
 
 =head1 SYNOPSIS
 
@@ -30,14 +30,6 @@ Art::Artwork - The base thing producted by artists
 
 Artwork is a Zydeco subclass of L<Art::Work>.
 
-=head1 EXTENDS
-
-=over
-
-=item L<C<Art::Work>>
-
-=back
-
 =head1 ROLES
 
 =over
