@@ -8,11 +8,4 @@ class Agent with Active {
 
     include Artist;
     include Collector;
-
-    class Public {
-        method visit {
-            say "I visited";
-        }
-    }
-
 }
